from .secret_factory import SecretFactory

secret_client = None
def get_secret(cloud, region, env, service_name):
    """
    Function to retrieve secrets.

    Parameters:
    cloud (str): Cloud Provider. Currently supports "aws" and "azure"
    region (str): Cloud Provider Region.
    env (str): Can take one of "dev", "staging", "greenprod" or "blueprod" values
    service_name (str): Resource for which the secret is required

    Returns:
    secret_value (json)
    """

    # Input validation
    if cloud not in ["aws", "azure"]:
        raise ValueError("Cloud Provider Not Supported. Use either 'aws' or 'azure'")

    global secret_client
    if not secret_client:
        secret_client = SecretFactory().get_secret_client()

    return secret_client.retrieve_secret(service_name, env, cloud, region)



from .base_secret import Secret


class AzureSecret(Secret):
    def retrieve_secret(self, service_name: str, env: str, cloud: str="aws", region_name: str="us-west-2"):
        raise NotImplementedError



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hx_secret_keeper']

package_data = \
{'': ['*']}

install_requires = \
['aws_secretsmanager_caching>=1.1.1,<2.0.0', 'boto3>=1.17.23,<2.0.0']

setup_kwargs = {
    'name': 'hx-secret-keeper',
    'version': '0.1.1',
    'description': '',
    'long_description': None,
    'author': 'Sujay S Kumar',
    'author_email': 'sujay@hypersonix.ai',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import base64
import json
import os
from botocore.exceptions import ClientError

import boto3
from aws_secretsmanager_caching import SecretCache, SecretCacheConfig

from .base_secret import Secret

class AWSSecret(Secret):
    def __init__(self):
        # Create a Secrets Manager client
        session = boto3.session.Session()
        self.client = session.client(
            service_name="secretsmanager",
            region_name=os.environ.get("AWS_DEFAULT_REGION", "us-west-2")
        )
        # Create a cache
        self.cache = SecretCache(SecretCacheConfig(), self.client)


    def retrieve_secret(self, service_name: str, env: str, cloud: str="aws", region_name: str="us-west-2"):
        secret_name = f"{env}/{cloud}/{region_name}/{service_name}"
        try:
            # Get secret string from the cache
            secret_value_response = self.cache.get_secret_string(secret_name)

        except ClientError as e:
            raise e
        else:
            return json.loads(secret_value_response)



import os

from .aws_secret import AWSSecret
from .azure_secret import AzureSecret


class SecretFactory(object):
    def get_secret_client(self):
        if os.environ.get("AWS_ACCESS_KEY_ID") and os.environ.get("AWS_SECRET_ACCESS_KEY"):
            return AWSSecret()
        else:
            return AzureSecret()
